@@ -1,19 +1,19 @@
 class Attribute:
 
     def __init__(self, builder, name, dtype=float, size=0):
-        self.core = builder.core
+        self.particulator = builder.particulator
         self.timestamp: int = 0
         self.data = None
         self.dtype = dtype
         self.size = size
         self.name = name
-        self.formulae = self.core.formulae
+        self.formulae = self.particulator.formulae
 
     def allocate(self, idx):
         if self.size >= 1:
-            self.data = self.core.IndexedStorage.empty(idx, (self.size, self.core.n_sd), dtype=self.dtype)
+            self.data = self.particulator.IndexedStorage.empty(idx, (self.size, self.particulator.n_sd), dtype=self.dtype)
         else:
-            self.data = self.core.IndexedStorage.empty(idx, (self.core.n_sd,), dtype=self.dtype)
+            self.data = self.particulator.IndexedStorage.empty(idx, (self.particulator.n_sd,), dtype=self.dtype)
 
     def set_data(self, data):
         self.data = data
