@@ -1,11 +1,11 @@
-from PySDM.physics import constants as const
-from PySDM.backends.numba import conf
-from PySDM.backends.numba.toms748 import toms748_solve
-import numba
 import numpy as np
 import math
 from functools import lru_cache
 from .warnings import warn
+import numba
+from PySDM.physics import constants as const
+from PySDM.backends.numba import conf
+from PySDM.backends.numba.toms748 import toms748_solve
 
 
 class CondensationMethods:
@@ -242,7 +242,7 @@ class CondensationMethods:
 
                     if not success:
                         break
-                    elif a != b:
+                    if a != b:
                         if a > b:
                             a, b = b, a
                             fa, fb = fb, fa
