@@ -7,11 +7,12 @@ from PySDM.backends.numba.impl._pair_methods import PairMethods
 from PySDM.backends.numba.impl._physics_methods import PhysicsMethods
 from PySDM.backends.numba.impl._index_methods import IndexMethods
 from PySDM.backends.numba.impl.condensation_methods import CondensationMethods
-from .impl.moments_methods import MomentsMethods
-from .impl.freezing_methods import FreezingMethods
+from PySDM.backends.numba.impl.moments_methods import MomentsMethods
+from PySDM.backends.numba.impl.freezing_methods import FreezingMethods
 from PySDM.backends.numba.impl._chemistry_methods import ChemistryMethods
 from PySDM.backends.numba.random import Random as ImportedRandom
 from PySDM.backends.numba.storage import Storage as ImportedStorage
+from PySDM.physics import Formulae
 
 
 class Numba(
@@ -29,8 +30,8 @@ class Numba(
 
     default_croupier = 'local'
 
-    def __init__(self, formulae):
-        self.formulae = formulae
+    def __init__(self, formulae=None):
+        self.formulae = formulae or Formulae()
         PhysicsMethods.__init__(self)
         ChemistryMethods.__init__(self)
         FreezingMethods.__init__(self)
