@@ -17,10 +17,10 @@ import inspect
 
 class Builder:
 
-    def __init__(self, n_sd, backend, formulae=Formulae()):
-        assert inspect.isclass(backend)
-        self.formulae = formulae
-        self.particulator = Particulator(n_sd, backend(formulae))
+    def __init__(self, n_sd, backend):
+        assert not inspect.isclass(backend)
+        self.formulae = backend.formulae
+        self.particulator = Particulator(n_sd, backend)
         self.req_attr = {'n': Multiplicities(self), 'volume': Volume(self), 'cell id': CellID(self)}
         self.aerosol_radius_threshold = 0
         self.condensation_params = None
@@ -72,7 +72,7 @@ class Builder:
             attributes['cell id'] = np.zeros_like(attributes['n'], dtype=np.int64)
         self.particulator.attributes = ParticlesFactory.attributes(self.particulator, self.req_attr, attributes)
 
-        for key in self.particulator.dynamics.keys():
+        for key in self.particulator.dynamics:
             self.particulator.timers[key] = WallTimer()
 
         return self.particulator
