@@ -7,12 +7,12 @@ class EulerianAdvection:
 
     def __init__(self, solvers):
         self.solvers = solvers
-        self.core = None
+        self.particulator = None
 
     def register(self, builder):
-        self.core = builder.core
+        self.particulator = builder.particulator
 
     def __call__(self):
-        self.core.env.get_predicted('qv').download(self.core.env.get_qv(), reshape=True)
-        self.core.env.get_predicted('thd').download(self.core.env.get_thd(), reshape=True)
+        self.particulator.env.get_predicted('qv').download(self.particulator.env.get_qv(), reshape=True)
+        self.particulator.env.get_predicted('thd').download(self.particulator.env.get_thd(), reshape=True)
         self.solvers()
