@@ -1,7 +1,9 @@
 import numpy as np
+from PySDM.physics import si
 
 m = np.inf
 c = np.inf
+unit = 1 / si.cm**2 / si.s
 
 class ABIFM:
     @staticmethod
@@ -11,4 +13,4 @@ class ABIFM:
 
     @staticmethod
     def J_het(a_w_ice):
-        return 10**(m * (1 - a_w_ice) + c)
+        return 10**(m * (1 - a_w_ice) + c) * unit
