@@ -17,15 +17,15 @@ class ParticlesVolumeSpectrum(SpectrumMomentProduct):
     def register(self, builder):
         builder.request_attribute('volume')
 
-        volume_bins_edges = builder.core.formulae.trivia.volume(self.radius_bins_edges)
-        self.attr_bins_edges = builder.core.bck.Storage.from_ndarray(volume_bins_edges)
+        volume_bins_edges = builder.particulator.formulae.trivia.volume(self.radius_bins_edges)
+        self.attr_bins_edges = builder.particulator.bck.Storage.from_ndarray(volume_bins_edges)
 
         super().register(builder)
 
-        self.shape = (*builder.core.mesh.grid, len(self.attr_bins_edges) - 1)
+        self.shape = (*builder.particulator.mesh.grid, len(self.attr_bins_edges) - 1)
 
     def get(self):
-        vals = np.empty([self.core.mesh.n_cell, len(self.attr_bins_edges) - 1])
+        vals = np.empty([self.particulator.mesh.n_cell, len(self.attr_bins_edges) - 1])
         self.recalculate_spectrum_moment(attr=f'volume', rank=1, filter_attr='volume')
 
         for i in range(vals.shape[1]):
@@ -34,5 +34,5 @@ class ParticlesVolumeSpectrum(SpectrumMomentProduct):
             self.download_spectrum_moment_to_buffer(rank=0, bin_number=i)
             vals[:, i] *= self.buffer.ravel()
 
-        vals *= 1 / np.diff(np.log(self.radius_bins_edges)) / self.core.mesh.dv
+        vals *= 1 / np.diff(np.log(self.radius_bins_edges)) / self.particulator.mesh.dv
         return vals
