@@ -14,8 +14,8 @@ class TotalParticleSpecificConcentration(MomentProduct):
     def get(self):
         self.download_moment_to_buffer('volume', rank=0)
         result = self.buffer.copy()  # TODO #217
-        self.download_to_buffer(self.core.environment['rhod'])
-        result[:] /= self.core.mesh.dv
+        self.download_to_buffer(self.particulator.environment['rhod'])
+        result[:] /= self.particulator.mesh.dv
         result[:] /= self.buffer
         const.convert_to(result, const.si.milligram**-1)
         return result
